@@ -36,17 +36,17 @@ from pylab import ginput
 
 # CoastSat modules
 from coastsat import SDS_tools, SDS_preprocess
+# from coastsat import classification
 from coastsat.classification import models
-
+from coastsat.classification import training_data
+from coastsat.classification import training_sites
 np.seterr(all='ignore') # raise/ignore divisions by 0 and nans
 
 # @todo remove this after testing imports
 def test_imports():
-    filepath_models=""
-    with importlib.resources.as_file(importlib.resources.files('classification').joinpath('models')) as f:
-        print(f)
-        filepath_models=os.path.abspath(f)
-    print(f"\nfilepath_models: {filepath_models}")
+    print(list(os.path.abspath(resource) for resource in importlib.resources.files(models).iterdir() if resource.is_file()))
+    print(list(os.path.abspath(resource) for resource in importlib.resources.files(training_data).iterdir() if resource.is_file()))
+    print(list(os.path.abspath(resource) for resource in importlib.resources.files(training_sites).iterdir() if resource.is_file()))
 
 # Main function for batch shoreline detection
 def extract_shorelines(metadata, settings):
@@ -98,10 +98,11 @@ def extract_shorelines(metadata, settings):
     collection = settings['inputs']['landsat_collection']
     # filepath_models = os.path.join(os.getcwd(), 'classification', 'models')
     # @todo test new imports
-    filepath_models=""
-    with importlib.resources.as_file(importlib.resources.files('classification').joinpath('models')) as f:
-        print(f)
-        filepath_models=os.path.abspath(f)
+    filepath_models = os.path.abspath(importlib.resources.files(models))
+    # filepath_models=""
+    # with importlib.resources.as_file(importlib.resources.files('classification').joinpath('models')) as f:
+    #     print(f)
+    #     filepath_models=os.path.abspath(f)
     # model_paths = list(os.path.abspath(resource) for resource in importlib.resources.files(models).iterdir() if resource.is_file())
 
     # initialise output structure
